/****************************************************************************
  Project: NITRO-SampleTools - TXLib - TextureViewer
  File:    mainBg.c

  Copyright 2004,2005 Nintendo Co.,Ltd.	All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  This Bg routine is called from main.

  $Log: mainBg.c,v $
  Revision 1.7  2005/06/20 06:46:11  mominoki
  Updated copyright. Made revision adjustments. 


  Revision 1.2	2004/07/26		mominoki
 Added DC_FlushRange().

  Revision 1.1	2004/04/15		mominoki
  Fixed comments.

  Revision 1.0	2004/01/27		mominoki
  Entered initial version.

  $NoKeywords: $
******************************************************************************/
#include <nitro.h>
#include "myLib/myLib_fontData.h"
#include "myLib/myLib_fontBgScr.h"

/******************************************************************************
	Definitions
******************************************************************************/
#define SCREEN_SIZE 			(32 * 24)

/******************************************************************************
	Global variables
******************************************************************************/
static u16			sMenuScr[SCREEN_SIZE];		// Menu screen
static u16			sInfoScr[SCREEN_SIZE];		// Information screen

/******************************************************************************
	Prototype declaration
******************************************************************************/
void MainBg_MenuScr_Init(void);
void MainBg_MenuScr_ClearAll(void);
void MainBg_MenuScr_Renew(void);

void MainBg_InfoScr_Init(void);
void MainBg_InfoScr_ClearAll(void);
void MainBg_InfoScr_Renew(void);
void MainBg_InfoScr_SetChar( char* pStr1, u8 x, u8 y, u8 colorIndex );
void MainBg_InfoScr_SetInt( u16 figure, u8 sw, u8 x, u8 y, u16 colorIndex );

//======================================================================
//	Menu screen
//======================================================================
/******************************************************************************
	MainBg_MenuScr_Init();

	Initialize BG
******************************************************************************/
void MainBg_MenuScr_Init(void)
{
	char* 	pChar;
	u8		x,y;

	GX_LoadBG1Char(fontCharData, 0, sizeof(fontCharData));				// Transfer character -> VRAM
	GX_LoadBGPltt(fontPaletteData, 0, sizeof(fontPaletteData));			// Palette -> VRAM transfer

	MainBg_MenuScr_ClearAll();

	x = 6;	y = 0;
	pChar = "NITRO Texture Viewer";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x], kFont_Red);

	x = 2;	y = 2;
	pChar = "START";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x], 	kFont_Blue);
	pChar = "Info:";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x+9], 	kFont_Green);
	pChar = "ON,OFF";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x+18], kFont_Blue);

	y++;
	pChar = "L+START";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x], 	kFont_Blue);
	pChar = "Camera:";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x+9], 	kFont_Green);
	pChar = "Reset";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x+18], kFont_Blue);

	y++;
	pChar = "R+START";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x], 	kFont_Blue);
	pChar = "Mode:";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x+9], 	kFont_Green);
	pChar = "DEC or MOD";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x+18], kFont_Blue);

	y++;
	pChar = "SELECT";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x], 	kFont_Blue);
	pChar = "Menu:";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x+9], 	kFont_Green);
	pChar = "ON,OFF";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x+18],	kFont_Blue);

	y++;
	pChar = "R+SELECT";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x], 	kFont_Blue);
	pChar = "palette0:";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x+9], 	kFont_Green);
	pChar = "Color or Tra";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x+18], kFont_Blue);

	y++;
	pChar = "A";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x], 	kFont_Blue);
	pChar = "Change Texture:";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x+9], 	kFont_Green);
	pChar = "+";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x+24], kFont_Blue);

	y++;
	pChar = "B";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x], 	kFont_Blue);
	pChar = "Change Texture:";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x+9], 	kFont_Green);
	pChar = "-";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x+24], kFont_Blue);

	y++;
	pChar = "L+A";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x], 	kFont_Blue);
	pChar = "Camera Z:";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x+9], 	kFont_Green);
	pChar = "+";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x+18], kFont_Blue);

	y++;
	pChar = "L+B";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x], 	kFont_Blue);
	pChar = "Camera Z:";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x+9], 	kFont_Green);
	pChar = "-";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x+18], kFont_Blue);

	y++;
	pChar = "L+UP";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x], 	kFont_Blue);
	pChar = "Camera Y:";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x+9], 	kFont_Green);
	pChar = "+";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x+18], kFont_Blue);

	y++;
	pChar = "L+DOWN";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x], 	kFont_Blue);
	pChar = "Camera Y:";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x+9], 	kFont_Green);
	pChar = "-";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x+18], kFont_Blue);

	y++;
	pChar = "L+LEFT";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x], 	kFont_Blue);
	pChar = "Camera X:";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x+9], 	kFont_Green);
	pChar = "-";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x+18], kFont_Blue);

	y++;
	pChar = "L+RIGHT";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x], 	kFont_Blue);
	pChar = "Camera X:";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x+9], 	kFont_Green);
	pChar = "+";
	MyLib_FontBgScr_SetChar((u8*)pChar, &sMenuScr[32*y + x+18], kFont_Blue);
}

/******************************************************************************
	MainBg_MenuScr_ClearAll();

	Clear BG screen used for menu
	Call when you want to erase menu from NitroMain().
******************************************************************************/
void MainBg_MenuScr_ClearAll(void)
{
	u32 i;

	for( i=0; i<SCREEN_SIZE; i++ )
	{
		sMenuScr[i] = 0;
	}
}

/******************************************************************************
	MainBg_MenuScr_Renew();

	Update the BG screen that is used for the menu
	CAn from NitroMain() at V-Blank time.
******************************************************************************/
void MainBg_MenuScr_Renew(void)
{
	DC_FlushRange(sMenuScr, sizeof(sMenuScr));
	GX_LoadBG1Scr(sMenuScr, 0, sizeof(sMenuScr));		// Transfer BG screen -> VRAM
}

//======================================================================
//	Information screen
//======================================================================
/******************************************************************************
	MainBg_InfoScr_Init();

	Initialize the BG screen that is used for information display.
	Call from NitroMain() only once at initialize time.
******************************************************************************/
void MainBg_InfoScr_Init(void)
{
	GX_LoadBG2Char(fontCharData, 0, sizeof(fontCharData));				// Transfer character -> VRAM
	GX_LoadBGPltt(fontPaletteData, 0, sizeof(fontPaletteData));			// Palette -> VRAM transfer

	MainBg_InfoScr_ClearAll();
}

/******************************************************************************
	MainBg_InfoScr_ClearAll();

	Clear the BG screen that is used for information display.
	Call from NitroMain() every frame before rewriting information.
******************************************************************************/
void MainBg_InfoScr_ClearAll(void)
{
	u32 i;

	for( i=0; i<SCREEN_SIZE; i++ )
	{
		sInfoScr[i] = 0;
	}
}

/******************************************************************************
	MainBg_InfoScr_Renew();

	Update the BG screen that is used for information display
	Call from NitroMain() at V-Blank time.
******************************************************************************/
void MainBg_InfoScr_Renew(void)
{
	DC_FlushRange(sInfoScr, sizeof(sInfoScr));
	GX_LoadBG2Scr(sInfoScr, 0, sizeof(sInfoScr));		// Transfer BG screen -> VRAM
}

/******************************************************************************
	MainBg_InfoScr_SetChar();

	Create BG screen character string that is used for information display
	Call as required after MainBg_InfoScr_ClearAll().
******************************************************************************/
void MainBg_InfoScr_SetChar( char* pStr1, u8 x, u8 y, u8 colorIndex )
{
	u8 posX = x;
	u8 posY = y;

	if( x > 31 ) posX = 31;
	if( y > 23 ) posY = 23;

	MyLib_FontBgScr_SetChar( (u8*)pStr1, &sInfoScr[32*posY + posX], colorIndex);
}

/******************************************************************************
	MainBg_InfoScr_SetInt();

	Create BG screen number string that is used for information display.
	Call as required after MainBg_InfoScr_ClearAll().
******************************************************************************/
void MainBg_InfoScr_SetInt( u16 figure, u8 sw, u8 x, u8 y, u16 colorIndex )
{
	u8 posX = x;
	u8 posY = y;

	if( x > 31 ) posX = 31;
	if( y > 23 ) posY = 23;

	MyLib_FontBgScr_SetU16( figure, &sInfoScr[32*posY + posX], colorIndex, sw );
}
