/****************************************************************************
  Project: NITRO-SampleTools - TXLib
  File:    TXLib_AlphaImage.cpp

  Copyright 2004,2005 Nintendo Co.,Ltd.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  Class handles the alpha component of CTexture

  $Log: TXLib_AlphaImage.cpp,v $
  Revision 1.7  2005/06/20 06:54:11  mominoki
  Changed copyright. Revision adjustments. 

  Revision 1.1  2004/04/15		mominoki
  Corrected comment

  Revision 1.0  2004/03/03		mominoki
  Initial registration

  $NoKeywords: $
 ***************************************************************************/
#define TLB_EXPORT_

#include <cstring>
#include <TXLib/Base/TXLib_AlphaImage.h>

namespace TXLib{

/*********************************************************************************************************
	TXLib::CAlphaImage::CAlphaImage

	Constructor
*********************************************************************************************************/
CAlphaImage::CAlphaImage()
: 
	m_available(false),
	m_width(0),
	m_height(0),
	m_alphaChannel()
{
}

/*********************************************************************************************************
	TXLib::CAlphaImage::CAlphaImage

	Copy Constructor
*********************************************************************************************************/
CAlphaImage::CAlphaImage
(
	const	CAlphaImage&			rAlphaImage				// CAlphaImage of copy source
) :
	m_available		(rAlphaImage.m_available		),
	m_width			(rAlphaImage.m_width			),
	m_height		(rAlphaImage.m_height			),
	m_alphaChannel	(rAlphaImage.m_alphaChannel	)
{
}

/*********************************************************************************************************
	TXLib::CAlphaImage::operator=

	Substitution operator
*********************************************************************************************************/
CAlphaImage&
CAlphaImage::operator=(
	const	CAlphaImage&			rAlphaImage				// CAlphaImage of copy source
)
{
	if (&rAlphaImage != this)
	{
		m_available	   = rAlphaImage.m_available;
		m_width		   = rAlphaImage.m_width;
		m_height	   = rAlphaImage.m_height;
		m_alphaChannel = rAlphaImage.m_alphaChannel;
	}
	return *this;
}

/*********************************************************************************************************
	TXLib::CAlphaImage::~CAlphaImage

	Destructor
*********************************************************************************************************/
CAlphaImage::~CAlphaImage()
{ 
	Clear(); // Clear
} 

/*********************************************************************************************************
		private
*********************************************************************************************************/
/*********************************************************************************************************
	TXLib::CAlphaImage::Clear

	Memory Clear
*********************************************************************************************************/
void 
CAlphaImage::Clear()
{
	m_available = false;
	m_width		= 0;
	m_height	= 0;

	m_alphaChannel.Clear();
}

/*********************************************************************************************************
		public
*********************************************************************************************************/
/*********************************************************************************************************
	TXLib::CAlphaImage::Create

	Create
*********************************************************************************************************/
void
CAlphaImage::Create(
				u16							width,						// Image size width
				u16						height,							// Image size height
				u8							initialAlpha					// Data default value
)
{
	m_available = true;
	m_width     = width;
	m_height    = height;

	m_alphaChannel  .Create( (width * height), initialAlpha   );
}

/*********************************************************************************************************
	TXLib::CAlphaImage::GetValue

	Get Alpha Value
*********************************************************************************************************/
inline void
CAlphaImage::GetValue(
				u8*							pAlpha,							// Data Pointer Alpha
				u16							x,							// X Coordinate
				u16							y							// Y Coordinate
) const
{
	assert( pAlpha != NULL );

	m_alphaChannel.GetValue( pAlpha, ( y * m_width ) + x  );
}

/*********************************************************************************************************
	TXLib::CAlphaImage::SetValue

	Set Alpha Value
*********************************************************************************************************/
inline void
CAlphaImage::SetValue( 
				u8							alpha,							// Data Alpha
				u16							x,							// X Coordinate
				u16							y							// Y Coordinate
)
{
	m_alphaChannel.SetValue( alpha, ( y * m_width ) + x );
}

} // namespace
