/****************************************************************************
  Project: NITRO-SampleTools - TXLib
  File:    TXLib_DirectColorImage.cpp

  Copyright 2004,2005 Nintendo Co.,Ltd.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  Class handling Direct color image component of CTexture.   
  Do not use when CTexture is color index.

  $Log: TXLib_DirectColorImage.cpp,v $
  Revision 1.7  2005/06/20 06:54:11  mominoki
  Changed copyright. Made revision adjustments.

  Revision 1.1  2004/04/15		mominoki
  Corrected comment

  Revision 1.0  2004/03/03		mominoki
  Initial registration

  $NoKeywords: $
***************************************************************************/
#define TLB_EXPORT_

#include <cstring>
#include <TXLib/Base/TXLib_DirectColorImage.h>

namespace TXLib{

/*********************************************************************************************************
	TXLib::CDirectColorImage::CDirectColorImage

	Constructor
*********************************************************************************************************/
CDirectColorImage::CDirectColorImage()
:
	m_available(false),
	m_width(0),
	m_height(0),
	m_redChannel(),
	m_greenChannel(),
	m_blueChannel()
{
}

/*********************************************************************************************************
	TXLib::CDirectColorImage::CDirectColorImage

	Copy constructor
*********************************************************************************************************/
CDirectColorImage::CDirectColorImage
(
	const	CDirectColorImage&		rDirectColorImage				// CDirectColorImage of copy source
) :
	m_available		(rDirectColorImage.m_available		),
	m_width			(rDirectColorImage.m_width			),
	m_height		(rDirectColorImage.m_height			),
	m_redChannel	(rDirectColorImage.m_redChannel		),
	m_greenChannel	(rDirectColorImage.m_greenChannel	),
	m_blueChannel	(rDirectColorImage.m_blueChannel	)
{
}

/*********************************************************************************************************
	TXLib::CDirectColorImage::operator=

	Assignment operator
*********************************************************************************************************/
CDirectColorImage&
CDirectColorImage::operator=(
	const	CDirectColorImage&			rDirectColorImage				// CDirectColorImage of copy source
)
{
	if (&rDirectColorImage != this)
	{
		m_available	   = rDirectColorImage.m_available;
		m_width		   = rDirectColorImage.m_width;
		m_height	   = rDirectColorImage.m_height;
		m_redChannel   = rDirectColorImage.m_redChannel;
		m_greenChannel = rDirectColorImage.m_greenChannel;
		m_blueChannel  = rDirectColorImage.m_blueChannel;
	}
	return *this;
}

/*********************************************************************************************************
	TXLib::CDirectColorImage::~CDirectColorImage

	Destructor
*********************************************************************************************************/
CDirectColorImage::~CDirectColorImage()
{
	Clear(); // Clear
} 

/*********************************************************************************************************
		private
*********************************************************************************************************/
/*********************************************************************************************************
	TXLib::CDirectColorImage::Clear

	Clear memory
*********************************************************************************************************/
void CDirectColorImage::Clear()
{
	m_available = false;
	m_width	    = 0;
	m_height    = 0;

	m_redChannel  .Clear();
	m_greenChannel.Clear();
	m_blueChannel .Clear();
}

/*********************************************************************************************************
		public
*********************************************************************************************************/
/*********************************************************************************************************
	TXLib::CDirectColorImage::Create

	Create
*********************************************************************************************************/
void
CDirectColorImage::Create(												
				u16					width,				// Image size width
				u16					height,				// Image size height
				u8					initialRed,			// Default value Red
				u8					initialGreen,		// Default value Green
				u8					initialBlue			// Default value Blue
)
{
	u32 memorySize = width * height;

	m_available = true;
	m_width     = width;
	m_height    = height;

	m_redChannel  .Create( memorySize, initialRed   );
	m_greenChannel.Create( memorySize, initialGreen );
	m_blueChannel .Create( memorySize, initialBlue  );
}

/*********************************************************************************************************
	TXLib::CDirectColorImage::GetValue

	Get Color value
*********************************************************************************************************/
inline void
CDirectColorImage::GetValue(
				u8*							pRed,							// Data Pointer Red
				u8*							pGreen,							// Data Pointer Green
				u8*							pBlue,							// Data Pointer Blue
				u16							x,								// X Coordinate
				u16							y								// Y Coordinate
) const
{
	assert( ( pRed != NULL )  && ( pGreen != NULL ) && ( pBlue  != NULL ) );

	u32 index = y * m_width + x;

	assert( index <= GetNumber() );

	m_redChannel.  GetValue( pRed, index  );
	m_greenChannel.GetValue( pGreen, index  );
	m_blueChannel. GetValue( pBlue , index );
}

/*********************************************************************************************************
	TXLib::CDirectColorImage::SetValue

	Set color value
*********************************************************************************************************/
inline void
CDirectColorImage::SetValue(
				u8							red,							// Data Red
				u8							green,							// Data Green
				u8							blue,							// Data Blue
				u16					 		x,								// X Coordinate
				u16							y								// Y Coordinate
)
{
	u32 index = y * m_width + x;

	assert( index <= GetNumber() );

	m_redChannel.  SetValue( red, index  );
	m_greenChannel.SetValue( green, index );
	m_blueChannel. SetValue( blue, index  );
}

} // namespace

