/****************************************************************************
  Project: NITRO-SampleTools - TXLib
  File:    TXLibUtility_Bmp.h

  Copyright 2004,2005 Nintendo Co.,Ltd.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  This is a class for inputting BMP data into a texture, and for outputting CTexture data as BMP data.

  $Log: TXLibUtility_Bmp.h,v $
  Revision 1.8  2005/06/20 06:54:11  mominoki
  Revised copyright. Made revision adjustments. 

  Revision 1.1  2004/04/15		mominoki
  Corrected comment

  Revision 1.0  2004/03/03		mominoki
  Initial registration

  $NoKeywords: $
 ***************************************************************************/

#ifndef TXLIBUTILITY_BMP_H_
#define TXLIBUTILITY_BMP_H_

#include <TXLib.h>

namespace TXLibUtility
{
	// Class
	class CBmp
	{
	public:
		// Structure
		typedef struct tInfoHeader
		{
			u32 	biSize;
			s32 	biWidth;
			s32 	biHeight;
			u16 	biPlanes;
			u16 	biBitCount;
			u32 	biCompression;
			u32 	biSizeImage;
			s32 	biXPelsPerMeter;
			s32 	biYPelsPerMeter;
			u32 	biClrUsed;
			u32 	biClrImportant;
		}tInfoHeader; 	// BMP BITMAPINFOHEADER Structure

		typedef struct tFileHeader
		{
			u16		bfType;	
			u32 	bfSize;
			u16 	bfReserved1;
			u16 	bfReserved2;
			u32 	bfOffBits;
		}tFileHeader; 	// BMP BITMAPFILEHEADER Structure

		// Define
		enum	tDefine{
			kDefine_infoHeaderByteSize	= 40,	 	// BITMAPINFOHEADER Byte Size
			kDefine_fileHeaderByteSize	= 14,	 	// BITMAPFILEHEADER Byte Size
		};	// Define

	private:
		// Function
		CBmp( const CBmp&		rBmp){};		// Copy constructor


		u16 GetNeedLine(
					u16							bitCount,						// Bit depth
					u16							width							// Width
		)const; // Get image size


		bool ReadBMPHEADER( 
					tFileHeader*				pFileHeader,					// BITMAPFILEHEADER Pointer
					tInfoHeader*				pInfoHeader,					// BITMAPINFOHEADER Pointer
			const	u8*							pMemory							// Input data pointer
		); // Load BMP header


		bool WriteBMPHEADER(
					u8*							pMemory,						// Output data pointer
					u32*						pDataSize,						// Output data size pointer
					u16							bitCount,						// Bit depth
					u16							width,							// Width
					u16							height,							// Height			
					u32							nColorUsed						// Actual number of palette colors
		) const;// Write BMP header


		void ReadDirectColorImage(
					TXLib::CDirectColorImage*	pDirectColorImage,				// Direct color image pointer
			const	u8*							pMemory,						// Input data pointer
					u16							width,							// Width
					u16							height							// Height
		); // Input memory data to DirectColorImage


		void WriteDirectColorImage(
					u8*							pMemory,						// Output data pointer
			const	TXLib::CDirectColorImage*	pDirectColorImage				// Direct color image pointer
		) const; // Output DirectColorImage to memory


		void ReadColorPalette(
					TXLib::CColorPalette*		pColorPalette,					// Color palette pointer
			const	u8*							pMemory,						// Input data pointer
					u32							nColorUsed						// Actual number of palette colors
		); // Input memory data to ColorPalette


		void WriteColorPalette(
					u8*							pMemory,						// Output data pointer
			const	TXLib::CColorPalette*		pColorPalette					// Color palette pointer
		) const; // Output ColorPalette to memory


		bool ReadColorIndexImage(
					TXLib::CColorIndexImage*	pColorIndexImage,				// Color index image
			const	u8*							pMemory,						// Input data pointer
					u16							bitCount,						// Bit depth
					u16							width,							// Width
					u16							height							// Height
		);// Input memory data to ColorIndexImage


		void WriteColorIndexImage(
					u8*							pMemory,						// Output data pointer
			const	TXLib::CColorIndexImage*	pColorIndexImage,				// Color index image
					u16							bitCount						// Bit depth
		) const; // Output ColorIndexImage to memory

	public:

		CBmp(){}																// Default constructor
		virtual ~CBmp(){}														// Destructor

		bool Read(
					TXLib::CTexture*		pTexture,							// Output CTexture pointer
			const	u8*						pMemory								// Input data pointer
		); // Load BMP data from memory

		bool Write(
					u8*						pMemory,							// Output data pointer
					u32*					pByteSize,							// Number of bytes output
					TXLib::CTexture*		pTexture							// CTexture Pointer
		) const; // Write BMP data to memory


		TXLib::CTexture::tType GetConvertType(
					TXLib::CTexture*		pTexture							// CTexture Pointer
		) const; // Get conversion format


		bool  GetDataByteSizeMax(
					u32*					pMemorySize,					// Memory size
					TXLib::CTexture*		pTexture						// CTexture Pointer
		) const; // Obtain the largest file size necessary to save a BMP file
	};
};
#endif