/****************************************************************************
  Project: NITRO-SampleTools - TXLib
  File:    TXLibUtilityEx_Bg.h

  Copyright 2004,2005 Nintendo Co.,Ltd.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  This class outputs CTexture data to BG data.

  $Log: TXLibUtilityEx_Bg.h,v $
  Revision 1.8  2005/06/20 06:54:11  mominoki
  Revised copyright. Made revision adjustments. 

  Revision 1.3	2004/10/27		mominoki
  Added bgAlignmentPaletteNumberFlg to Write() arguments. 
  Changed to allow selection of whether to output palette with 16 colors when 4 bit, and 256 colors when 8 bit, during BG output.  

  Revision 1.2	2004/07/28		mominoki
  Added offsetColorIndex to Write(), MakeTextBg() arguments.
  Added functionality that offsets color index values with palette16, palette256, affine, palette256x16.

  Revision 1.1	2004/04/15		mominoki
  Fixed comments.

  Revision 1.0	2004/03/03		mominoki
  Entered initial version.

  $NoKeywords: $
 ***************************************************************************/
#ifndef MYUTILITY_BG_H_
#define MYUTILITY_BG_H_

#include <TXLib.h>

namespace TXLibUtilityEx
{
	// Class
	class CBg
	{
	public:
		enum	tDefine{
			kDefine_Bg8					= 8,			// Block size (one block for 8x8 character)
			kDefine_block64				= 64,			// Number of characters in one block
			kDefine_flipShift			= 10,		 	// Screen data flip position shift count
			kDefine_paletteShift		= 12,		 	// Screen data palette position shift count
			kDefine_textCharNumberMax	= 1024,		 	// Text BG maximum character count
			kDefine_affineCharNumberMax	= 256,		 	// Affine BG maximum character count
		};	// Definition

		// BG format
		enum tType{
			kType_text_palette16,				// Text BG palette16
			kType_text_palette256,				// Text BG palette256
			kType_affine,						// Affine BG
			kType_exAffine_palette256x16,		// Affine extension BG palette 256 16 palette
			kType_exAffine_palette256Bmp,		// Affine extension BG palette256 BMP
			kType_exAffine_direct,				// Affine extension BG DIRECT BMP
			kType_big256Bmp,					// Large screen BMP
			kType_not					= 0xff,	// No specification
		};

		enum tFlip{
			kType_notFlip,						// No flip
			kType_hFlip,						// hFilp
			kType_vFlip,						// vFlip
			kType_hvFlip,						// hFlip & vFlip
		};

		// BG memory output structure
		typedef struct tMemory
		{
			u8* 	pCharData;						// Character data pointer
			u32 	charDataByteSize;				// Character data byte size
			u8* 	pPaletteData;					// Palette data pointer
			u32 	paletteDataByteSize;			// Palette data byte size
			u8*		pScreenData;					// Screen data pointer
			u32		screenDataByteSize;				// Screen data byte size
		}tMemory;

	private:
		bool MakeTextBg(
					TXLib::CColorIndexImage*	pCharData,						// Character data
					u16*						pNumberChar,					// Total number of characters
					TXLib::CByteData*			pScreenData,					// Screen data
					tType						type,							// BG format
					bool						hFlip,							// There is H flip
					bool						vFlip,							// There is V flip
					bool						compressFlg,					// There is character compression
					u8							paletteNumber,				// Palette number
					u8							offsetColorIndex			// Color index off set value
		) const; // Create text BG

		void MakeBmpScreen(
					TXLib::CByteData*			pScreen,						// Screen
			const	TXLib::CDirectColorImage*	pDirectColorImage,				// Direct color image
			const	TXLib::CAlphaImage*			pAlphaImage						// Alpha image
		) const;


		void WriteChar(
					u8*							pCharData,						// Character data pointer
			const	TXLib::CColorIndexImage*	pColorIndexImage,				// Color index
					u8							bitCount						// Bit depth
		) const;


		void WritePalette(
					u8*							pPaletteData,					// Palette data pointer
					u32*						pPaletteDataByteSize,			// Palette data byte size
			const	TXLib::CColorPalette*		pColorPalette					// Color palette
		) const;


		void WriteScreen(
					u8*							pScreenData,					// Character data pointer
					u32*						pScreenDataByteSize,				// Character data byte size
			const	TXLib::CByteData*			pScreen							// Screen
		) const;


	public:
		CBg(){}																	// Default constructor
		virtual ~CBg(){}														// Destructor

		bool Write(
					tMemory*					pBgMemory,						// BG memory
					TXLib::CTexture*			pTexture,						// CTexture pointer
					tType						bgType,							// BG format
					bool						hFlip,							// There is H flip
					bool						vFlip,							// There is V flip
					bool						compressFlg,					// There is character compression
					u8							paletteNumber,				// Palette number
					bool						bgAlignmentPaletteNumberFlg,	//  Palette number alignment flag
					u8							offsetColorIndex			// Color index off sett value
		) const;

		bool GetDataByteSizeMax(
					u32*						pCharDataByteSize,				// Character data size
					u32*						pPaletteDataByteSize,			// Palette data size
					u32*						pScreenDataByteSize,			// Screen data size
					u16							width,							// Width
					u16							height,							// Height
					tType						bgType							// BG format that is output
		) const;	

	};
};
#endif