/****************************************************************************
  Project: NITRO-SampleTools - TXLib
  File:    MyColorProcessor.cpp

  Copyright 2004,2005 Nintendo Co.,Ltd.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  This is the color processing class. It is a function customized to perform only RGBA to Index Color conversion through color subtraction.
  All other functions are left to CDefaultColorProcessor.

  $Log: MyColorProcessor.cpp,v $
  Revision 1.8  2005/06/20 06:54:11  mominoki
  Changed copyright. Made revision adjustments. 

  Revision 1.1  2004/04/15		mominoki
  Corrected comment

  Revision 1.0  2004/03/03		mominoki
  Initial registration

  $NoKeywords: $
 ***************************************************************************/
#include "stdafx.h"
#include <TXLib.h>
#include "MyColorProcessor.h"

/*********************************************************************************************************
	TXLib::CMyColorProcessor::ConvertToPaletteType

	Create palette format texture
	- Calll from CTexture::ChangeDirectToPaletteType
*********************************************************************************************************/
bool
CMyColorProcessor::ConvertToPaletteType(
		TXLib::CTexture*				pTexture
)
{
	// Error Processing
	assert( pTexture );
	assert( pTexture->GetColorIndexImage().IsAvailable() && pTexture->GetColorPalette().IsAvailable() && 
			pTexture->GetDirectColorImage().IsAvailable());

	TXLib::CColorPalette	colorMemory;

	// Create color memory for processing
	colorMemory.Create( pTexture->GetWidth() * pTexture->GetHeight(), 0, 0, 0 );

	// Copy direct image to the color memory (no color subtraction)
	CDefaultColorProcessor::CreateColorMemory( &colorMemory, &pTexture->GetDirectColorImage(), NULL, 0 );

	// Until the target number of colors is achieved, expand the shared region and subtract color.
	int bit = 5;
	while( colorMemory.GetNumber() > pTexture->GetColorPalette().GetNumber() )
	{
		colorMemory.CommonLowerBit(bit);						//Pseudo convert the 8-bit color values to ?bit
		colorMemory.CutCommonColor();							// Cut shared colors
		bit--;													// Expand the shared region
	}
	
	// Copy the created color memory to the palette
	pTexture->GetColorPalette() = colorMemory;

	// Create color index
	// Assign a palette to the direct color image.
	for( u16 y = 0; y<pTexture->GetHeight(); y++)
	{
		for( u16 x=0; x<pTexture->GetWidth(); x++)
		{
			int index;
			u8 red, green, blue;

			pTexture->GetDirectColorImage().GetValue( &red, &green, &blue, x, y  );			// Get image color value
			index = FindNearColor( &pTexture->GetColorPalette(), red, green, blue, -1 );	// Search color index from palette
			if( index == -1) return false;

			pTexture->GetColorIndexImage().SetValue( (u8)index, x, y );		// Set index value
		}
	}

	return true;
}


