/****************************************************************************
  Project: NITRO-SampleTools - TXLib
  File:    customColorProcessor.cpp

   Copyright 2004,2005 Nintendo Co.,Ltd.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  - This sample customizes the color processor class. It customizes only the function that reduces colors from direct to the color index. All other functions are handled by CDefaultColorProcessor.
  By setting this class in TXLib, color processing in TXLib can use the customized collor processor class.

  $Log: customColorProcessor.cpp,v $
  Revision 1.8  2005/06/20 06:54:11  mominoki
  Changed copyright. Made revision adjustments. 

  Revision 1.1  2004/04/15		mominoki
  Corrected comment

  Revision 1.0  2004/03/03		mominoki
  Initial registration

  $NoKeywords: $
 ***************************************************************************/
#include "stdafx.h"
#include <cstdio>
#include <cstdlib>
#include <TXLib.h>
#include "../TXLibUtility/include/TXLibUtility.h"
#include "MyColorProcessor.h"

int _tmain(int argc, _TCHAR* argv[])
{
	printf("Executing. Please wait.\n");

	TXLib::CTexture texture;

	// Convert image file To CTexture.
	if( !TXLibUtility::Load(
			&texture,
			"../common/inputFiles/mario_128x128_direct.tga"
	) )
	{
		printf("Failed to load image file.\n"); exit(1);
	}

	// Set color processor class
	CMyColorProcessor colorProcessor;
	texture.SetColorProcessor( &colorProcessor );

	// Convert
	if( !texture.Convert( TXLib::CTexture::kType_palette256 ))
	{
		printf("Failed to convert the texture format.\n"); exit(1);
	}

	// Output NTF
	if( !TXLibUtility::SaveNtf(
				"outputFiles/after.c",				// NTF file name
				&texture,							// CTexture
				false,								// Text format
				NULL,								// Input image file name
				false,								// does not output TextureViewer file
				true								// align to NTF image size
	) )
	{
		printf("Failed to output NTF file.\n"); exit(1);
	}

	// Output image file
	if( !TXLibUtility::Save(
			"outputFiles/after.bmp",
			&texture
	) )
	{
		printf("Failed to output image file.\n"); exit(1);
	}

	printf("Succeeded.\n");

	return 0;
}

