/****************************************************************************
  Project: NITRO-SampleTools - TXLib
  File:    customTex4x4ColorProcessor.cpp

  Copyright 2004,2005 Nintendo Co.,Ltd.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  - This sample customizes the color processor class. It customizes only the function that extracts 0 - 4 colors from the block when converting to tex4x4. All other functions are handled by CDefaultColorProcessor. By setting this class in TXLib, color processing in TXLib can use the customized collor processor class.

  $Log: customTex4x4ColorProcessor.cpp,v $
  Revision 1.8  2005/06/20 06:54:11  mominoki
  Changed copyright. Made revision adjustments.

  Revision 1.1  2004/04/15		mominoki
  Corrected comment

  Revision 1.0  2004/03/03		mominoki
  Initial registration

  $NoKeywords: $
 ***************************************************************************/
#include "stdafx.h"
#include <cstdio>
#include <cstdlib>
#include <TXLib.h>
#include "../TXLibUtility/include/TXLibUtility.h"
#include "MyColorProcessor.h"

int _tmain(int argc, _TCHAR* argv[])
{
	TXLib::CTexture		texture;
	TXLib::CDefaultColorProcessor::tConvertFactor	factor;

	std::memset( (void*)&factor, 0, sizeof(TXLib::CDefaultColorProcessor::tConvertFactor));

	int		mode, red, green, blue;

	// Create conversion coefficient
	printf("Select a mode. (0: Transparent Color Mode, 1: 4-Color Mode)\n");
	scanf( "%d", &mode );
	factor.transparencyFlg = (mode == 0) ? true : false;

	printf("Is there linear interpolation? (0: No linear interpolation, 1: Linear interpolation)\n");
	scanf( "%d", &mode );
	factor.algorithm =(TXLib::CDefaultColorProcessor::tAlgorithm) mode;

	if( factor.transparencyFlg )
	{
		printf("Use transparent color? Use alpha? (0: Transparent color, 1: Alpha)\n");
		scanf("%d", &mode );
		factor.alphaColorCutFlg = (mode == 0) ? false : true;

		if( !factor.alphaColorCutFlg )
		{
			printf("Specify the transparent color in RGB order. (Red: 255 0 0)\n");
			scanf("%d %d %d", &red, &green, &blue );
			factor.transparentColor.red		= (u8)red;
			factor.transparentColor.green	= (u8)green;
			factor.transparentColor.blue	= (u8)blue;
		}
	}
	
	printf("Share palettes and compress the number of palettes? (0: No, 1: Yes)\n");
	scanf( "%d", &mode );
	factor.compressFlg = (mode == 0) ? false: true;

	if( factor.compressFlg )
	{
		printf("Specify the color region for palette sharing in RGB order. (0 - 31)\n"
				"If all values are set to 0, only palettes having the exact same colors will be shared.\n");
		scanf( "%d %d %d", &red, &green, &blue );
		factor.commonColorRange.red		= red;
		factor.commonColorRange.green	= green;
		factor.commonColorRange.blue	= blue;
	}

	printf("Executing. Please wait.\n");

	// Convert image file to CTexture.
	if( !TXLibUtility::Load(
			&texture,
			"../common/inputFiles/mario_128x128_direct.tga"
	))
	{
		printf("Failed to load image file.\n"); exit(1);
	}

	// Set color processor class and conversion coefficient (Set before converting!)
	CMyColorProcessor colorProcessor;

	colorProcessor.SetConvertFactor( &factor );
	texture.SetColorProcessor( &colorProcessor );


	// Convert
	if( !texture.Convert( TXLib::CTexture::kType_tex4x4 ))
	{
		printf("Failed to convert the texture format.\n"); exit(1);
	}

	// Output NTF
	if( !TXLibUtility::SaveNtf(
				"outputFiles/after.c",				// Output NTF file name
				&texture,							// CTexture
				false,								// Texture format
				NULL,								// Input image file name
				false,								// Does ot output TextureViewer file
				true								// Aligh to NTF size
	) )
	{
		printf("Failed to output NTF file.\n"); exit(1);
	}

	// Output image file
	if( !TXLibUtility::Save(
				"outputFiles/after.bmp",
				&texture
	) )
	{
		printf("Failed to output image file.\n"); exit(1);
	}

	printf("Succeeded.\n");

	return 0;
}

