/****************************************************************************
  Project: NITRO-SampleTools - TXLib
  File:    ntexconv.h

  Copyright 2004,2005 Nintendo Co.,Ltd.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

	Based on the option, this tool converts BMP or TGA files to NTF and then outputs.

  $Log: ntexconv.h,v $
  Revision 1.8  2005/06/20 06:54:11  mominoki
  Changed copyright. Made revision adjustments. 

  Revision 1.2	2004/10/27		mominoki
  Added palette number alignment option (-bgnap) for BG output.
  When specified, output only the number of used palettes. 
  When not specified, if 16 color, use 16 color; if 256 color, use 256 color. 

  Revision 1.1	2004/04/15		mominoki  
  Revised comments. 

  Revision 1.0	2004/03/03		mominoki
  Initial registration. 

  $NoKeywords: $
 ***************************************************************************/
#ifndef NTEXCONV_H_
#define NTEXCONV_H_

#define USE_BG	// Use BG

//---------------------------------------------------------------------------
// options
//---------------------------------------------------------------------------
enum tOption{
	kOption_InputPathName,			// (None)
	kOption_View,					// -v
	kOption_Help,					// -h
	kOption_Script,					// -s
	kOption_TextureViewer,			// -tv

	kOption_NtfPathName,			// -o
	kOption_NotNtf,					// -no
	kOption_NtfBinary,				// -b
	kOption_OptionPathName,			// -d
	kOption_PalettePathName,		// -p
	kOption_TextureFormat,			// -f
	kOption_NotAlignmentNtfSize,	// -nal
	// tex4x4
	kOption_Algorithm0,				// -a0
	kOption_Algorithm1,				// -a1
	kOption_Algorithm2,				// -a2
	kOption_Algorithm3,				// -a3
	kOption_TransparencyAlpha,		// -ta
	kOption_TransparencyColor,		// -tc=r,g,b
	kOption_CompressPalette,		// -cp=r,g,b
	kOption_NotCompressPalette,		// -ncp
#ifdef USE_BG
	// BG
	kOption_Bg,						// -bg
	kOption_BgBinary,				// -bgb
	kOption_BgPathName,				// -bgo
	kOption_BgFormat,				// -bgf
	kOption_BgPaletteNumber,		// -bgp
	kOption_BgNotAlignmentPaletteNumber,		// -bgnap
	kOption_BgOffsetImage,			// -bgof
	kOption_BgNotVFlip,				// -bgnv
	kOption_BgNotHFlip,				// -bgnh
	kOption_BgNotCompressChar,		// -bgnc
#endif
};

#ifdef USE_BG
#define		OPTION_NUMBER_MAX		(12 + 8 + 10)	// No. of option arrays
#else
#define		OPTION_NUMBER_MAX		(12 + 8    )	// No. of option arrays
#endif

// option character string
static char optionStr[ OPTION_NUMBER_MAX ][6] = {
	"none",	"v",	"h",	"s",	"tv",
	"o",	"no",	"b",	"d",	"p",
	"f",	"nal",
	// tex4x4
	"a0",	"a1",	"a2",	"a3",	"ta",
	"tc=",	"cp=",	"ncp",
#ifdef USE_BG
	// BG
	"bg",	"bgb",	"bgo",	"bgf",	"bgp", "bgnap",
	"bgof", "bgnv",	"bgnh", "bgnc"
#endif
};

//---------------------------------------------------------------------------
// Script
//---------------------------------------------------------------------------
#define		SCRIPT_LINEDATA_MAX		( _MAX_PATH * 5 )	// Maximum number of characters in one line of script

//---------------------------------------------------------------------------
// Error
//---------------------------------------------------------------------------
// Error number
enum tErrorStatus{
	kErrorStatus_Success,					// Success
	kErrorStatus_NotOptionNumber,			// Error: option count
	kErrorStatus_NotOption,					// Error: Issued option not registered
	kErrorStatus_OverInputPathNumber,		// Error: Multiple input files
	kErrorStatus_NotInputPathName,			// Error: No input file
	kErrorStatus_DifferentInputExtName,		// Incorrect input file extension
	kErrorStatus_FalseNtfPathName,			// Error: Incorrect output NTF path name
	kErrorStatus_DifferentOptionExtName,	// Error: Incorrect output option file extension
	kErrorStatus_DifferentPaletteExtName,	// Error: Incorrect extension for Texture file used in palette
	kErrorStatus_DifferentTextureType,		// Error: Incorrect conversion texture format
	kErrorStatus_TransparencyColor,			// Error: Incorrect transparent color setting
	kErrorStatus_CompressPalette,			// Error: Incorrect common range setting for palette count compression
#ifdef USE_BG
	// BG
	kErrorStatus_DifferentBgType,			// Error: Not BG format
	kErrorStatus_FalseBgPathName,			// Error: Incorrect BG path name
	kErrorStatus_BgPaletteNumber,			// Error: BG palette number
	kErrorStatus_BgOffsetImage,			// Error: Off set image value
#endif
	// Script
	kErrorStatus_LoadScriptFile,			// Error: Script file load
	kErrorStatus_DuplicateScriptFile,		// Error: Load script file more than once
	// Errors during TXLib process
	kErrorStatus_LoadFile,					// Error: File load
	kErrorStatus_Convert,					// Error: Texture conversion
	kErrorStatus_SaveOptionFile,			// Error: Option file output
	kErrorStatus_SaveNtfFile,				// Error: NTF output
#ifdef USE_BG
	kErrorStatus_SaveBgFile					// Error: BG output
#endif
};

#define		ERRORSTATUS_STRING_MAX		300	// Maximum character count for error message

// Error message
	static char errorStatus_Success[] =	"Successful\n\n";

	static char errorStatus_NotOptionNumber[] =
		"Error!!: option Argument\n"
		"         The number of option arguments is incorrect.\n"
		"         Verify them again.\n\n";

	static char errorStatus_NotOption[] = 
		"Error!!: option\n"
		"         An unregistered option has been specified.\n"
		"         Verify the option again.\n\n";

	static char errorStatus_OverInputPathNumber[] = 
		"Error!!: Number of Input Image Files\n"
		"         Two or more image files have been specified for input.\n"
		"         Specify only one!\n\n";

	static char errorStatus_NotInputPathName[] = 
		"Error!!: Input Image File Path Name Specification\n"
		"         No path name has been entered for the input image file.\n"
		"         Enter a path name for the input image file!\n\n";

	static char errorStatus_DifferentInputExtName[] = 
		"Error!!: Input Image File Extension\n"
		"         The extension for the input file is incorrect or missing.\n"
		"         Verify that the file has a TGA (.tga) or BMP (.bmp) extension!\n\n";

	static char errorStatus_FalseNtfPathName[] = 
		"Error!!: Incorrect Path Name for Output NTF\n"
		"         An incorrect path name has been specified for the NTF.\n"
		"         Verify that the path name does not use Japanese or illegal characters (/,-,%, etc.)!\n\n";

	static char errorStatus_DifferentOptionExtName[] = 
		"Error!!: Option File Extension\n"
		"         The extension for the option file is incorrect or missing.\n"
		"         Verify that the file has a TGA (.tga) or BMP (.bmp) extension!\n\n";

	static char errorStatus_DifferentPaletteExtName[] = 
		"Error!!: Palette File Extension\n"
		"         The extension for the palette file is incorrect or missing.\n"
		"         Verify that the file has a TGA (.tga) or BMP (.bmp) extension!\n\n";

	static char errorStatus_DifferentTextureType[] = 
		"Error!!: Texture Format for Conversion\n"
		"         The texture format to be converted is incorrect.\n"
		"         Verify the texture format!\n\n";

	static char errorStatus_TransparencyColor[] = 
		"Error!!: Transparent Color Setting\n"
		"         The transparent color setting is incorrect.\n"
		"         Verify the setting (values for r, g, and b are in the range of 0 (0x00) - 255 (0xff))!\n\n";

	static char errorStatus_CompressPalette[] = 
		"Error!!: Shared Color Range Settings\n"
		"         The settings for the shared color range to compress the number of palettes is incorrect.\n"
		"         Verify the setting (values for r, g, and b are in the range of 0 (0x00) - 31 (0x1f))!\n\n";

	#ifdef USE_BG
	// BG Errors
	static char errorStatus_DifferentBgType[] =
		"Error!!: BG Format for Conversion\n"
		"         The BG format to be converted is incorrect.\n"
		"         The formats that can be converted are palette16, palette256, direct,\n"
		"         palette256x16, palette256Bmp or big256Bmp\n"
		"         Verify the BG format!\n\n";

	static char errorStatus_FalseBgPathName[] = 
		"Error!!: Incorrect Path Name for Output BG\n"
		"         An incorrect path name has been specified for BG.\n"
		"         Verify that the path name does not use Japanese or illegal characters (/,-,%, etc.)!\n\n";

	static char errorStatus_BgPaletteNumber[] = 
		"Error!!: BG Palette Number\n"
		"         The BG palette number is incorrect.\n"
		"         Verify the palette number (within the range 0 (0x0) - 15 (0xf))!\n\n";

	static char errorStatus_BgOffsetImage[] = 
		"Error!!: Offset Image\n"
		"         The Offset Image is incorrect.\n";
	#endif
	// Script Errors
	static char errorStatus_LoadScriptFile[] = 
		"Error!!: Script File Load\n"
		"         Failed to load the script file.\n"
		"         Verify whether the specified file exists!\n\n";

	static char errorStatus_DuplicateScriptFile[] = 
		"Error!!: Duplicate Script File Load\n"
		"         An attempt to load the same script file twice was made.\n"
		"         Delete the script options in the script file!\n\n";

	// TXLib Processing Errors
	static char errorStatus_LoadFile[] = 
		"Error!!: File Load\n"
		"         Failed to load the file.\n"
		"         Verify whether the specified file exists!\n\n";

	static char errorStatus_Convert[] = 
		"Error!!: Texture Conversion\n"
		"         Failed to convert texture.\n"
		"         Verify the conversion settings!\n\n";

	static char errorStatus_SaveOptionFile[] = 
		"Error!!: Option File Output\n"
		"         Failed to output option file.\n"
		"         Verify the output path!\n\n";

	static char errorStatus_SaveNtfFile[] = 
		"Error!!: NTF Output\n"
		"         Failed to output NTF.\n"
		"         Verify that the input image file is a NITRO texture size (8x8 - 1024x1024)!\n"
		"         Verify the output path!\n\n";

	#ifdef USE_BG
	static char errorStatus_SaveBgFile[] = 
		"Error!!: BG Output\n"
		"         Failed to output BG.\n"
		"         Verify the output path and the input image file size (must be BG size for NITRO)!\n"
		"         When using text BG output, verify that the number of characters has not been exceeded \n"
		"           (text: 1024; affine: 256)!\n"
		"         Verify that the format can be output with BG (palette16, palette256, direct,\n"
		"           palette256x16, palette256Bmp or big256Bmp)!\n\n";
	#endif


// Error message array
static char* pErrorStatusStr[] = { 
	errorStatus_Success,
	errorStatus_NotOptionNumber,
	errorStatus_NotOption,
	errorStatus_OverInputPathNumber,
	errorStatus_NotInputPathName,
	errorStatus_DifferentInputExtName,
	errorStatus_FalseNtfPathName,
	errorStatus_DifferentOptionExtName,
	errorStatus_DifferentPaletteExtName,
	errorStatus_DifferentTextureType,
	errorStatus_TransparencyColor,
	errorStatus_CompressPalette,
#ifdef USE_BG
	// BG
	errorStatus_DifferentBgType,
	errorStatus_FalseBgPathName,
	errorStatus_BgPaletteNumber,
	errorStatus_BgOffsetImage,
#endif
	// Script
	errorStatus_LoadScriptFile,
	errorStatus_DuplicateScriptFile,
	// Error during TXLib process
	errorStatus_LoadFile,
	errorStatus_Convert,
	errorStatus_SaveOptionFile,
	errorStatus_SaveNtfFile,
#ifdef USE_BG
	errorStatus_SaveBgFile,
#endif
};

#endif

