/****************************************************************************
  Project: NITRO-SampleTools - TXLib
  File:    outputMultiNTF.cpp

  Copyright 2004,2005 Nintendo Co.,Ltd.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  - Load multiple TGA and BMP files and output to NTF without converting texture format.

  $Log: outputMultiNTF.cpp,v $
  Revision 1.8  2005/06/20 06:54:11  mominoki
  Revised copyright. Made revision adjustments. 

  Revision 1.1  2004/04/15		mominoki
  Corrected comment

  Revision 1.0  2004/03/03		mominoki
  Initial registration

  $NoKeywords: $
 ***************************************************************************/
#include "stdafx.h"
#include <cstdio>
#include <cstdlib>
#include <TXLib.h>
#include "../TXLibUtility/include/TXLibUtility.h"

#define FILE_NUMBER		2
#define PATHNAME		256

// Input image file path name
const char	inputFilePath[ FILE_NUMBER ][ PATHNAME ] = 	{
	"../common/inputFiles/mario_128x128_palette256.bmp",
	"../common/inputFiles/mario_128x128_direct.tga"
};

// NTF path name
const char	outputFilePath[ FILE_NUMBER ][ PATHNAME ] = {
	"outputFiles/after_palette256.c",
	"outputFiles/after_direct.c"
};

int _tmain(int argc, _TCHAR* argv[])
{
	TXLib::CTexture texture;
	const char*		pPathName;

	for( int i=0; i<FILE_NUMBER; i++)
	{
		// Convert image file to CTexture
		pPathName = &inputFilePath[i][0];

		if( !TXLibUtility::Load(
				&texture,	// CTexture
				pPathName	// Input image file path name
		) )
		{
			printf("Failed to load image file number %d. \n", i ); exit(1);
		}

		// Output NTF
		pPathName = &outputFilePath[i][0];

		if( !TXLibUtility::SaveNtf(
					pPathName,							// NTF file name
					&texture,							// CTexture
					false,								// Text format
					NULL,								// Input image file name
					false,								// Does not output TextureViewer file
					true								// Aligh to NTF size
		) )
		{
			printf("Failed to output NTF file number %d.\n", i ); exit(1);
		}
	}

	printf("Succeeded.\n");
	return 0;
}

