/****************************************************************************
  Project: NITRO-SampleTools - TXLib
  File:    TXLib_AlphaImage.h

  Copyright 2004,2005 Nintendo Co.,Ltd.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  This is a class that handles the alpha that makes up CTexture.

  $Log: TXLib_AlphaImage.h,v $
  Revision 1.7  2005/06/20 06:54:11  mominoki
  Updated copyright. Made revision adjustments. 

  Revision 1.1  2004/04/15		mominoki
  Revised the comments.

  Revision 1.0  2004/03/03		mominoki
  Initial registration.

  $NoKeywords: $
 ***************************************************************************/

#ifndef TXLIB_ALPHAIMAGE_H_
#define TXLIB_ALPHAIMAGE_H_

#include <TXLib_Typedef.h>
#include <TXLib/Base/TXLib_Data.h>

namespace TXLib
{
#ifdef TLB_EXPORT_
	class __declspec(dllexport)CAlphaImage
#else
	class __declspec(dllimport)CAlphaImage
#endif
	{
	private:
		bool		m_available;		// Whether or not the data can be used
		u16			m_width;			// Image size : width
		u16			m_height;			// Image size : height
		CData		m_alphaChannel;		// Data alpha

	public:
		CAlphaImage();									// Default constructor

		CAlphaImage( const CAlphaImage&	rAlphaImage);	// Copy constructor

		virtual ~CAlphaImage();							// Destructor

		bool			IsAvailable()		const { return m_available; }
		u16				GetWidth()			const { return m_width; }
		u16				GetHeight()			const { return m_height; }

		const CData&	GetAlphaChannel()	const 	{ return m_alphaChannel; }
		CData&	GetAlphaChannel()		 { return m_alphaChannel;}

		void Clear();		// Clear


		void Create(
					u16							width,							// Image size : width
					u16							height,							// Image size : height
					u8							initialAlpha					// Initial data value
		); // Creation


		inline void GetValue( 
					u8*							pAlpha,							// Data pointer alpha
					u16							x,								// X-coordinate
					u16							y								// Y-coordinate
		) const; // Gets the alpha value


		inline void SetValue( 
					u8							alpha,							// Data alpha
					u16							x,								// X-coordinate
					u16							y								// Y-coordinate
		); // Sets the alpha value


		CAlphaImage& operator=( 
			const CAlphaImage& rAlphaImage
		);	 // Substitute operator
	};
};

#endif
