/****************************************************************************
  Project: NITRO-SampleTools - TXLib
  File:    TXLib_ColorIndexImage.h

  Copyright 2004,2005 Nintendo Co.,Ltd.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  This class handles the color index that makes up CTexture. This is not used if CTexture is Direct.

  $Log: TXLib_ColorIndexImage.h,v $
  Revision 1.7  2005/06/20 06:54:11  mominoki
  Updated copyright. Made revision adjustments. 

  Revision 1.1  2004/04/15		mominoki
  Revised the comments.

  Revision 1.0  2004/03/03		mominoki
  Initial registration.

  $NoKeywords: $
 ***************************************************************************/
#ifndef TXLIB_COLORINDEXIMAGE_H_
#define TXLIB_COLORINDEXIMAGE_H_

#include <TXLib_Typedef.h>
#include <TXLib/Base/TXLib_Data.h>

namespace TXLib
{
#ifdef TLB_EXPORT_
	class __declspec(dllexport)CColorIndexImage
#else
	class __declspec(dllimport)CColorIndexImage
#endif
	{
	private:
		bool				m_available;		// Whether or not the data can be used.
		u16					m_width;			// Image size : width
		u16					m_height;			// Image size : height
		CData				m_colorIndexData;	// Data

	public:
		CColorIndexImage();												// Default constructor
						
		CColorIndexImage( const CColorIndexImage& rColorIndexaImage);	// Copy constructor

		virtual ~CColorIndexImage();									// Destructor

		bool	IsAvailable()	const { return m_available; }
		u16		GetWidth()		const{ return m_width; }
		u16		GetHeight()		const{ return m_height; }
		u32		GetNumber()		const{ return ( m_width * m_height ); }	// Gets the data number

		const CData&	GetColorIndexData()	const 	{ return m_colorIndexData; }
		CData&	GetColorIndexData()		 { return m_colorIndexData;}

		void Clear();			// Clear


		void Create(
					u16					width,				// Image size : width
					u16					height				// Image size : height
		); // Creation

		inline void GetValue(
					u8*					pData,				// Data pointer
					u16					x,					// X-coordinate
					u16					y					// Y-coordinate
		) const; // Gets the color index value.

		inline void SetValue(
					u8					data,				// Data
					u16					x,					// X-coordinate
					u16					y					// Y-coordinate
		); // Sets the color index value.

		CColorIndexImage& operator=( const CColorIndexImage& rColorIndexImage);	 // Substitute operator
	};
};
#endif