/****************************************************************************
  Project: NITRO-SampleTools - TXLib
  File:    TXLib_ColorPalette.h

  Copyright 2004,2005 Nintendo Co.,Ltd.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  This class handles the color palette that makes up CTexture. This is not used when CTexture is Direct.

  $Log: TXLib_ColorPalette.h,v $
  Revision 1.7  2005/06/20 06:54:11  mominoki
  Updated copyright. Made revision adjustments. 

  Revision 1.1  2004/04/15		mominoki
  Revised the comments.

  Revision 1.0  2004/03/03		mominoki
  Initial registration.

  $NoKeywords: $
 ***************************************************************************/
#ifndef TXLIB_COLORPALETTE_H_
#define TXLIB_COLORPALETTE_H_

#include <TXLib_Typedef.h>
#include <TXLib/Base/TXLib_Data.h>

namespace TXLib
{
#ifdef TLB_EXPORT_
	class __declspec(dllexport)CColorPalette
#else
	class __declspec(dllimport)CColorPalette
#endif
	{
	private:
		bool		m_available;		// Whether or not the data can be used.
		CData		m_redChannel;		// Red data
		CData		m_greenChannel;		// Green data
		CData		m_blueChannel;		// Blue data

	public:
		CColorPalette();										// Default constructor

		CColorPalette( const CColorPalette&	rColorPalette);		// Copy constructor

		virtual ~CColorPalette();								// Destructor

		bool	IsAvailable()				const	{ return m_available; }
		u32		GetNumber()					const	{ return m_redChannel.GetByteSize();}

		const CData&	GetRedChannel()		const	{ return m_redChannel;}
		const CData&	GetGreenChannel()	const 	{ return m_greenChannel; }
		const CData&	GetBlueChannel()	const 	{ return m_blueChannel; }
		CData&	GetRedChannel()		 { return m_redChannel;}
		CData&	GetGreenChannel()	 { return m_greenChannel; }
		CData&	GetBlueChannel()	 { return m_blueChannel; }


		void Clear();			// Clear


		void Create(
					u32							number,							// Data quantity
					u8							initialRed,						// Initial red value
					u8							initialGreen,					// Initial green value
					u8							initialBlue						// Initial blue value
		); // Creation


		inline void GetValue( 
					u8*							pRed,							// Red data pointer
					u8*							pGreen,							// Green data pointer
					u8*							pBlue,							// Blue data pointer
					u32							index							// Index
		) const; // Gets the color value


		inline void SetValue( 
					u8							red,							//Red data
					u8							green,							// Green data
					u8							blue,							// Blue data
					u32							index							// Index
		); // Sets the color value


		void CutCommonColor(); // Cuts the common colors


		void ChangeNumber( 
					u32							number							// Data number to be changed
		); // Changes the color number of the palette


		int FindColor(
					u8							red,
					u8							green,
					u8							blue
		); // Finds the designated color from the color palette , then returns its index.


		void QuickSortTopDown(																				
					bool						topDown								// true: descending order  false: ascending order
		); // Sorts the color palette colors in descending (true) or ascending (false) order.


		void CommonLowerBit(
					u8							virtualBit							// Virtual changed bit value
		); // By sharing the lower bits of the 8-bit color value, the bit value displayed with the virtual argument will change.


		CColorPalette& operator=( 
			const	CColorPalette& rColorPalette
		);	 // Substitute operator
	};
};

#endif