/****************************************************************************
  Project: NITRO-SampleTools - TXLib
  File:    TXLib_DirectColorImage.h

  Copyright 2004,2005 Nintendo Co.,Ltd.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  This class handles the direct color images that make up CTexture. This is not used when CTexture is the color index.

  $Log: TXLib_DirectColorImage.h,v $
  Revision 1.7  2005/06/20 06:54:11  mominoki
  Updated copyright. Made revision adjustments. 

  Revision 1.1  2004/04/15		mominoki
  Revised the comments.

  Revision 1.0  2004/03/03		mominoki
  Initial registration.

  $NoKeywords: $
 ***************************************************************************/
#ifndef TXLIB_DIRECTCOLORIMAGE_H_
#define TXLIB_DIRECTCOLORIMAGE_H_

#include <TXLib_Typedef.h>
#include <TXLib/Base/TXLib_Data.h>

namespace TXLib
{
#ifdef TLB_EXPORT_
	class __declspec(dllexport)CDirectColorImage
#else
	class __declspec(dllimport)CDirectColorImage
#endif
	{
	private:
		bool		m_available;		// Whether or not the data can be used.
		u16			m_width;			// Image size : width
		u16			m_height;			// Image size : height
		CData		m_redChannel;		// Red data
		CData		m_greenChannel;		// Green data
		CData		m_blueChannel;		// Blue data

	public:
		CDirectColorImage();											// Default constructor

		CDirectColorImage( const CDirectColorImage&	rDirectColorImage);	// Copy constructor

		virtual ~CDirectColorImage();									// Destructor 


		bool		IsAvailable()	const { return m_available; }
		u16			GetWidth()		const { return m_width; }
		u16			GetHeight()		const { return m_height; }
		u32			GetNumber()		const { return ( m_width * m_height ); }

		const CData&	GetRedChannel()		const	{ return m_redChannel;}
		const CData&	GetGreenChannel()	const 	{ return m_greenChannel; }
		const CData&	GetBlueChannel()	const 	{ return m_blueChannel; }
		CData&	GetRedChannel()		 { return m_redChannel;}
		CData&	GetGreenChannel()	 { return m_greenChannel; }
		CData&	GetBlueChannel()	 { return m_blueChannel; }

		void Clear();		// Clear


		void Create(												
					u16							width,							// Image size : width
					u16							height,							// Image size : height
					u8							initialRed,						// Initial red value
					u8							initialGreen,					// Initial green value
					u8							initialBlue						// Initial blue value
		); // Creation


		inline void GetValue(									
					u8*							pRed,							// Red data pointer
					u8*							pGreen,							// Green data pointer
					u8*							pBlue,							// Blue data pointer
					u16							x,								// X-coordinate
					u16							y								// Y-coordinate
		) const; // Gets the color value


		inline void SetValue(
					u8							red,							// Red data
					u8							green,							// Green data
					u8							blue,							// Blue data
					u16							x,								// X-coordinate
					u16							y								// Y-coordinate
		); // Sets the color value


		CDirectColorImage& operator=(
			const CDirectColorImage& rDirectColorImage
		);	 // Substitute operator
	};
};

#endif
