/****************************************************************************
  Project: NITRO-SampleTools - TXLib
  File:    TXLib_Texture.h

  Copyright 2004,2005 Nintendo Co.,Ltd.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  This handles the texture class.

  $Log: TXLib_Texture.h,v $
  Revision 1.7  2005/06/20 06:54:11  mominoki
  Updated copyright. Made revision adjustments. 

  Revision 1.1  2004/04/15		mominoki
 Revised the comments.

  Revision 1.0  2004/03/03		mominoki
  Initial registration.

  $NoKeywords: $
 ***************************************************************************/
#ifndef TXLIB_TEXTURE_H_
#define TXLIB_TEXTURE_H_

#include <TXLib_Define.h>
#include <TXLib_Typedef.h>
#include <TXLib/Base/TXLib_ColorIndexImage.h>
#include <TXLib/Base/TXLib_AlphaImage.h>
#include <TXLib/Base/TXLib_ColorPalette.h>
#include <TXLib/Base/TXLib_DirectColorImage.h>
#include <TXLib/Base/TXLib_Data.h>
#include <TXLib/Base/TXLib_ByteData.h>
#include <TXLib/Convert/TXLib_ColorProcessor.h>
#include <TXLib/Convert/TXLib_DefaultColorProcessor.h>

namespace TXLib
{
#ifdef TLB_EXPORT_
	class __declspec(dllexport)CTexture
#else
	class __declspec(dllimport)CTexture
#endif
	{
	public:
		// Texture type
		enum	tType{
			kType_palette4,
			kType_a5i3,
			kType_palette16,
			kType_a3i5,
			kType_palette256,
			kType_tex4x4,
			kType_direct,
			kType_not		= 0xff
		};

	protected:
		CColorIndexImage		m_colorIndexImage;
		CColorPalette			m_colorPalette;
		CDirectColorImage		m_directColorImage;
		CAlphaImage				m_alphaImage;
		CData					m_colorPaletteAttribute;
		CByteData				m_colorPaletteAddress;
		tType					m_type;						// Texture format
		CColorProcessor*		m_pColorProcessor;			// Color processor object

		//--------------------------------------------------------------
		//	Function
		//--------------------------------------------------------------
		bool GetTex4x4Palette( 
					CColorPalette*			pDstColorPalette,				// Color memory
			const	CColorPalette*			pSrcColorPalette,				// Color memory
					u8						attribute,						// Palette attribute
					u16						paletteAddress					// Palette address
		); // Gets the tex4x4 palette from the color memory


		bool ChangePaletteTypeToDirect(
		); // Changes the palette format to direct


		bool ChangeDirectToPaletteType(
					tType				type							// Texture format
		); // Changes direct to the palette format


		bool ChangePaletteType(
					tType				type							// Texture format
		); // Changes the palette format to a different palette format


		bool ChangeTex4x4ToDirect(
		); // Changes tex4x4 to direct


		bool ChangeDirectToTex4x4(
		); // Changes direct to tex4x4

	public:
		CTexture();											// Default contstructor
		CTexture( const CTexture&		rTexture);			// Copy constructor
		virtual ~CTexture();								// Destructor

		//--------------------------------------------------------------
		//	Gets the member variable and sets the function
		//--------------------------------------------------------------
		CColorIndexImage&		GetColorIndexImage()		{ return m_colorIndexImage; }
		CColorPalette&			GetColorPalette()			{ return m_colorPalette; }
		CDirectColorImage&		GetDirectColorImage()		{ return m_directColorImage; }
		CAlphaImage&			GetAlphaImage()				{ return m_alphaImage; }
		CData&					GetColorPaletteAttribute()	{ return m_colorPaletteAttribute; }
		CByteData&				GetColorPaletteAddress()	{ return m_colorPaletteAddress; }

		inline u16				GetWidth()		const;									// Gets the width
		inline u16				GetHeight()		const;									// Gets the height
		inline tType			GetType()		const		{ return m_type; }			// Gets the texture format
		inline void				SetType( tType type )		{ m_type = type; }			// Sets the texture format

		CColorProcessor*		GetColorProcessor()		{ return m_pColorProcessor; }	// Gets the color processor object

		inline void SetColorProcessor(	
				CColorProcessor*				pColorProcessor							// Color processor object
		); // Sets the color processor object

		//--------------------------------------------------------------
		//	Function
		//--------------------------------------------------------------
		void Clear(); // Clears the member variable


		bool Convert(
					tType				convertType						// Texture format that changes
		); // Changes from another texture format


		bool IsPaletteType(
		) const; // Determines whether or not the texture format is the palette format


		bool AlignmentImageSize(
					u16					width,							// Size : width
					u16					height							// Size : height
		); // Adjusts the texture size to the designated size


		CTexture& operator=(
			const CTexture&		rTexture);
	};
};

#endif