/****************************************************************************
  Project: NITRO-SampleTools - TXLib
  File:    TXLib_Ntf.h

  Copyright 2004,2005 Nintendo Co.,Ltd.  All rights reserved.

  These coded instructions, statements, and computer programs contain
  proprietary information of Nintendo of America Inc. and/or Nintendo
  Company Ltd., and are protected by Federal copyright law.  They may
  not be disclosed to third parties or copied or duplicated in any form,
  in whole or in part, without the prior written consent of Nintendo.

  This class is for the importation of NTF(Iris Texture File) data into CTexture, and
  for the output of CTexture data to NTF data.
  CNtf derives CTexture.

  $Log: TXLib_Ntf.h,v $
  Revision 1.7  2005/06/20 06:54:11  mominoki
  Updated copyright. Made revision adjustments. 

  Revision 1.1  2004/04/15		mominoki
  Revised the comments

  Revision 1.0  2004/03/03		mominoki
  Initial registration.

  $NoKeywords: $
 ***************************************************************************/
#ifndef TXLIB_NTF_H_
#define TXLIB_NTF_H_

#include <TXLib_Typedef.h>


namespace TXLib
{
	class CTexture;

#ifdef TLB_EXPORT_
	class __declspec(dllexport)CNtf
#else
	class __declspec(dllimport)CNtf
#endif
	{
	public:
		// NTF memory output structure
		typedef struct tMemory
		{
			u8* 	pTexelData;						// Texel data pointer
			u32 	texelDataByteSize;				// Texel data byte size
			u8* 	pPaletteData;					// Palette data pointer
			u32 	paletteDataByteSize;			// Palette data byte size
			u8* 	pPaletteIndexData;				// Palette index data pointer
			u32 	paletteIndexDataByteSize;		// Palette index data byte size
		}tMemory;

		// Definition
		enum tDefine{
			kDefine_sizeMax			= 1024,	// CNtf image size   Largest value (texel)
		};

	private:
		CNtf( const CNtf&		rNtf){};		// Copy constructor

	public:
		CNtf(){};								// Default constructor
		virtual ~CNtf(){};						// Destructor


		s32 GetNearNTFSize(
				u16			size					// Original texture
		) const; // Gets the NTF size closest to the current size


		bool Write( 
					tMemory*					pNTFMemory,							// tMemory
					CTexture*					pTexture,							// CTexture pointer
					bool						sizeAlignmentFlg					// NTF size adjustment flag
		)const; // Writes NTF data to memory


		bool GetDataByteSize(												
					u32*						pTexelDataByteSize,					// Texel data byte size
					u32*						pPaletteDataByteSize,				// Palette date byte size
					u32*						pPaletteIndexDataByteSize,			// Palette index byte size
					CTexture*					pTexture,							// CTexture pointer
					bool						sizeAlignmentFlg					// NTF size adjustment flag
		)const; // Gets the memory size needed for Ntf memory output
	};
};
#endif
